summaryrefslogtreecommitdiffstats
path: root/src/prefDVD.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/prefDVD.cpp')
-rw-r--r--src/prefDVD.cpp64
1 files changed, 32 insertions, 32 deletions
diff --git a/src/prefDVD.cpp b/src/prefDVD.cpp
index d0aef30..03c81dd 100644
--- a/src/prefDVD.cpp
+++ b/src/prefDVD.cpp
@@ -9,76 +9,76 @@
#include "prefDVD.h"
-#include <qvariant.h>
-#include <qlabel.h>
+#include <tqvariant.h>
+#include <tqlabel.h>
#include <kurlrequester.h>
-#include <qcheckbox.h>
-#include <qspinbox.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
+#include <tqcheckbox.h>
+#include <tqspinbox.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
#include "kurlrequester.h"
#include "klineedit.h"
#include "kpushbutton.h"
/*
* Constructs a prefDVD as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/
-prefDVD::prefDVD( QWidget* parent, const char* name, WFlags fl )
- : QWidget( parent, name, fl )
+prefDVD::prefDVD( TQWidget* tqparent, const char* name, WFlags fl )
+ : TQWidget( tqparent, name, fl )
{
if ( !name )
setName( "prefDVD" );
- prefDVDLayout = new QGridLayout( this, 1, 1, 11, 6, "prefDVDLayout");
+ prefDVDLayout = new TQGridLayout( this, 1, 1, 11, 6, "prefDVDLayout");
- lblworkDir = new QLabel( this, "lblworkDir" );
- lblworkDir->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)5, 0, 0, lblworkDir->sizePolicy().hasHeightForWidth() ) );
+ lblworkDir = new TQLabel( this, "lblworkDir" );
+ lblworkDir->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)5, 0, 0, lblworkDir->sizePolicy().hasHeightForWidth() ) );
prefDVDLayout->addWidget( lblworkDir, 0, 0 );
urOutput = new KURLRequester( this, "urOutput" );
- urOutput->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, urOutput->sizePolicy().hasHeightForWidth() ) );
+ urOutput->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)0, 0, 0, urOutput->sizePolicy().hasHeightForWidth() ) );
prefDVDLayout->addMultiCellWidget( urOutput, 0, 0, 1, 2 );
- ckK3b = new QCheckBox( this, "ckK3b" );
+ ckK3b = new TQCheckBox( this, "ckK3b" );
prefDVDLayout->addMultiCellWidget( ckK3b, 2, 2, 0, 2 );
- ckAutoBurn = new QCheckBox( this, "ckAutoBurn" );
- ckAutoBurn->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)0, 0, 0, ckAutoBurn->sizePolicy().hasHeightForWidth() ) );
+ ckAutoBurn = new TQCheckBox( this, "ckAutoBurn" );
+ ckAutoBurn->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)1, (TQSizePolicy::SizeType)0, 0, 0, ckAutoBurn->sizePolicy().hasHeightForWidth() ) );
prefDVDLayout->addMultiCellWidget( ckAutoBurn, 3, 3, 0, 2 );
- textLabel1_2 = new QLabel( this, "textLabel1_2" );
+ textLabel1_2 = new TQLabel( this, "textLabel1_2" );
prefDVDLayout->addWidget( textLabel1_2, 1, 0 );
- sbSize = new QSpinBox( this, "sbSize" );
- sbSize->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, sbSize->sizePolicy().hasHeightForWidth() ) );
- sbSize->setMinimumSize( QSize( 80, 0 ) );
+ sbSize = new TQSpinBox( this, "sbSize" );
+ sbSize->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, sbSize->sizePolicy().hasHeightForWidth() ) );
+ sbSize->setMinimumSize( TQSize( 80, 0 ) );
sbSize->setMaxValue( 9000 );
sbSize->setLineStep( 100 );
sbSize->setValue( 4400 );
prefDVDLayout->addWidget( sbSize, 1, 1 );
- ckQuickScan = new QCheckBox( this, "ckQuickScan" );
+ ckQuickScan = new TQCheckBox( this, "ckQuickScan" );
prefDVDLayout->addMultiCellWidget( ckQuickScan, 4, 4, 0, 2 );
- spacer1 = new QSpacerItem( 21, 110, QSizePolicy::Minimum, QSizePolicy::Expanding );
+ spacer1 = new TQSpacerItem( 21, 110, TQSizePolicy::Minimum, TQSizePolicy::Expanding );
prefDVDLayout->addItem( spacer1, 7, 2 );
- ckDvdAuthor = new QCheckBox( this, "ckDvdAuthor" );
+ ckDvdAuthor = new TQCheckBox( this, "ckDvdAuthor" );
prefDVDLayout->addMultiCellWidget( ckDvdAuthor, 5, 5, 0, 2 );
- ckDelTmpFiles = new QCheckBox( this, "ckDelTmpFiles" );
+ ckDelTmpFiles = new TQCheckBox( this, "ckDelTmpFiles" );
prefDVDLayout->addMultiCellWidget( ckDelTmpFiles, 6, 6, 0, 2 );
languageChange();
- resize( QSize(600, 347).expandedTo(minimumSizeHint()) );
+ resize( TQSize(600, 347).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
}
@@ -87,7 +87,7 @@ prefDVD::prefDVD( QWidget* parent, const char* name, WFlags fl )
*/
prefDVD::~prefDVD()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*
@@ -99,16 +99,16 @@ void prefDVD::languageChange()
setCaption( tr2i18n( "prefDVD" ) );
lblworkDir->setText( tr2i18n( "Output directory" ) );
ckK3b->setText( tr2i18n( "Burn with k3b" ) );
- ckK3b->setAccel( QKeySequence( tr2i18n( "Alt+B" ) ) );
+ ckK3b->setAccel( TQKeySequence( tr2i18n( "Alt+B" ) ) );
ckAutoBurn->setText( tr2i18n( "Auto burn" ) );
- ckAutoBurn->setAccel( QKeySequence( tr2i18n( "Alt+T" ) ) );
+ ckAutoBurn->setAccel( TQKeySequence( tr2i18n( "Alt+T" ) ) );
textLabel1_2->setText( tr2i18n( "DVD size" ) );
ckQuickScan->setText( tr2i18n( "Quick scan" ) );
- ckQuickScan->setAccel( QKeySequence( tr2i18n( "Alt+Q" ) ) );
+ ckQuickScan->setAccel( TQKeySequence( tr2i18n( "Alt+Q" ) ) );
ckDvdAuthor->setText( tr2i18n( "use dvdAuthor for copy without menus" ) );
- ckDvdAuthor->setAccel( QKeySequence( tr2i18n( "Alt+D" ) ) );
+ ckDvdAuthor->setAccel( TQKeySequence( tr2i18n( "Alt+D" ) ) );
ckDelTmpFiles->setText( tr2i18n( "Clear output directory on exit" ) );
- ckDelTmpFiles->setAccel( QKeySequence( tr2i18n( "Alt+Y" ) ) );
+ ckDelTmpFiles->setAccel( TQKeySequence( tr2i18n( "Alt+Y" ) ) );
}
#include "prefDVD.moc"
@@ -9,76 +9,76 @@
#include "kpushbutton.h"
/*
- * Constructs a prefDVD as a child of 'parent', with the
+ * Constructs a prefDVD as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/